@@ -98,14 +98,23 @@ def sort_excel_file():
             / f"{input_file_name_without_extension}_sorted.xlsx"
         ).resolve()
 
+        # Fix duplicate output file issue.
+        test_output_file_absolute_path = pathlib.Path(
+            output_file_absolute_path
+        ).resolve()
+
         copy_count = 1
-        while output_file_absolute_path.exists():
-            output_file_absolute_path = (
+        while test_output_file_absolute_path.exists():
+            test_output_file_absolute_path = (
                 output_folder_absolute_path
                 / f"{ output_file_absolute_path.stem }_{copy_count}.xlsx"
             )
             copy_count += 1
 
+        output_file_absolute_path = pathlib.Path(
+            test_output_file_absolute_path
+        ).resolve()
+
         excel_definition_file_absolute_path = None
 
         if args.excel_definition_file is not None:
