@@ -191,13 +191,16 @@ def output_to_excel_file(
 
     for column_index in range(len(columns)):
         cell = sheet.cell(row=1, column=column_index + 1)
-        cell.value = columns[column_index]
+        # There are three kinds of Cells. Only the Cell has the value attribute.
+        if hasattr(cell, "value"):
+            setattr(cell, "value", columns[column_index])
 
     if stories is not None:
         for row_index in range(len(stories)):
             for column_index, column_name, _, _, _, _, _ in excel_definition_columns:
                 cell = sheet.cell(row=row_index + 2, column=column_index)
-                cell.value = stories[row_index].format_value(column_name)
+                if hasattr(cell, "value"):
+                    setattr(cell, "value", stories[row_index].format_value(column_name))
 
     wb.save(str(file))
     wb.close()
