@@ -1,6 +1,6 @@
 import re
 from datetime import datetime
-from decimal import *
+from decimal import Decimal
 from operator import attrgetter
 from typing import Any
 
@@ -25,8 +25,8 @@ __all__ = [
 def convert_to_bool(raw: Any) -> bool:
     if type(raw) is bool:
         return raw
-    raw = str(raw).strip().upper()
-    if raw == "YES":
+    value = str(raw).strip().upper()
+    if value == "YES" or value == "TRUE":
         return True
     else:
         return False
@@ -44,7 +44,7 @@ def convert_to_decimal(raw: Any) -> Decimal:
         return Decimal(0)
 
 
-def convert_to_datetime(raw: Any) -> datetime:
+def convert_to_datetime(raw: Any) -> "datetime | None":
     if type(raw) is datetime:
         return raw
     if raw is None:
@@ -72,7 +72,7 @@ class Story(object):
             else:
                 setattr(self, column[1], None)
 
-    def __getitem__(self, property_name) -> "Milestone | Any":
+    def __getitem__(self, property_name) -> Any:
         return getattr(self, property_name)
 
     def format_value(self, property_name: str) -> str:
@@ -116,19 +116,19 @@ class Story(object):
                 self[column_name].calc_priority(sprint_schedule)
 
     # Currently, comparing story only consider the Priority properties.
-    def __lt__(self, __o: object) -> bool:
+    def __lt__(self, __o: "Story | None") -> bool:
         return self.factory.compare_story(self, __o) < 0
 
-    def __le__(self, __o: object) -> bool:
+    def __le__(self, __o: "Story | None") -> bool:
         return self.factory.compare_story(self, __o) <= 0
 
-    def __gt__(self, __o: object) -> bool:
+    def __gt__(self, __o: "Story | None") -> bool:
         return self.factory.compare_story(self, __o) > 0
 
-    def __ge__(self, __o: object) -> bool:
+    def __ge__(self, __o: "Story | None") -> bool:
         return self.factory.compare_story(self, __o) >= 0
 
-    def __eq__(self, __o: object) -> bool:
+    def __eq__(self, __o: "Story | None") -> bool:
         return self.factory.compare_story(self, __o) == 0
 
     # For CSV consideration.
@@ -151,7 +151,7 @@ class StoryFactory(object):
         self._columns = columns
         self._compare_rules = self.__generate_compare_rules()
 
-    def __generate_compare_rules(self) -> "list[tuple]":
+    def __generate_compare_rules(self) -> "list[tuple[str, int]]":
         compare_rules = []
         for _, column_name, _, _, _, inline_weights, _ in self._columns:
             if inline_weights > 0:
@@ -164,13 +164,14 @@ class StoryFactory(object):
         return self._columns
 
     @property
-    def compare_rules(self):
+    def compare_rules(self) -> "list[tuple[str, int]]":
         return self._compare_rules
 
     def create_story(self) -> Story:
         return Story(self)
 
-    def compare_story(self, a: Story, b: Story) -> int:
+    # TODO: Need to include all sort strategies.
+    def compare_story(self, a: "Story | None", b: "Story | None") -> int:
         """
         Compare two stories.
 
@@ -185,16 +186,22 @@ class StoryFactory(object):
             0: means a == b
             -1: means a < b
         """
+        if a is None or b is None:
+            raise ValueError("The compare stories cannot be None.")
+
         if a.factory != b.factory or a.factory != self or b.factory != self:
             raise ValueError("The compare stories were built by different factory.")
 
-        if len(self.compare_rules) == 0:
+        rules_count = len(self.compare_rules)
+
+        if rules_count == 0:
             return 0
 
         skip_index_of_a = []
         skip_index_of_b = []
-        count = len(self.compare_rules)
+        count = rules_count
         while count > 0:
+            # property_value, property_location
             highest_property_of_a = None
             highest_property_of_b = None
             for i in range(len(self.compare_rules)):
@@ -218,8 +225,15 @@ class StoryFactory(object):
                 if b[self.compare_rules[i][0]] > highest_property_of_b[0]:
                     highest_property_of_b = (b[self.compare_rules[i][0]], i)
 
-            skip_index_of_a.append(highest_property_of_a[1])
-            skip_index_of_b.append(highest_property_of_b[1])
+            if highest_property_of_a is None:
+                highest_property_of_a = (Priority.NA, count)
+            else:
+                skip_index_of_a.append(highest_property_of_a[1])
+
+            if highest_property_of_b is None:
+                highest_property_of_b = (Priority.NA, count)
+            else:
+                skip_index_of_b.append(highest_property_of_b[1])
 
             # priority value
             if highest_property_of_a[0] > highest_property_of_b[0]:
@@ -271,6 +285,8 @@ def _internal_sort_stories_by_property_and_order(
 def sort_stories_by_raise_ranking(
     stories: "list[Story]", excel_definition: Exceldefinition
 ) -> "list[Story]":
+    if stories is None:
+        return []
     sort_rules = []
     excel_definition_columns = excel_definition.get_columns()
 
@@ -291,7 +307,7 @@ def sort_stories_by_raise_ranking(
 
     sort_rules.sort(key=lambda x: x[1], reverse=True)
 
-    result = None
+    result = []
 
     for property_name, _ in sort_rules:
         result = _raise_story_ranking_by_property(stories, property_name)
@@ -303,14 +319,14 @@ def _raise_story_ranking_by_property(
     stories: "list[Story]", property_name: str
 ) -> "list[Story]":
     if stories is None or len(stories) == 0:
-        return
+        return stories
     # Use first story as example
     if not hasattr(stories[0], property_name):
-        return
+        return stories
     # Only bool indicator for now
     if type(getattr(stories[0], property_name)) is not bool:
-        return
-    result = [None] * len(stories)
+        return stories
+    result: list[Story] = [stories[0]] * len(stories)
     j = 0
     for i in range(len(stories)):
         if getattr(stories[i], property_name) is True:
